# Interlligent Automation Library
This is an RPA STP Library

## Installation
'''pip install iautolib'''

## How to use it?
Go to your favorite IDE or text editor and import the module thus 
import iautolib

## License

© 2020 Patrick Adu-Amankwah

This repository is licensed under the MIT License.
See LICENSE for details.